@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maillock.c,v 1.16 2007/07/12 14:38:47 smarinier Exp $
+ * $Id: maillock.c,v 1.18 2008/02/17 13:13:25 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -50,7 +50,7 @@
 #include <stdio.h>
 #include <time.h>
 #include <string.h>
-#ifdef _MSC_VER
+#ifdef WIN32
 #	include "win_etpan.h"
 #endif
 #ifdef HAVE_LIBLOCKFILE
@@ -197,7 +197,7 @@ static int lock_common(const char * filename, int fd, short locktype)
       if (now > start + LOCKTO_GLOB) {
         return -1;
       }
-#endif // SEBTRY
+#endif /* SEB_TRY */
 	}
   }
   return 0;	/* SEB 20070709 */
@@ -241,7 +241,7 @@ static int lock_common(const char * filename, int fd, short locktype)
   
   time(&start);
   while (1) {
-    int fd;
+    int fd2;
     struct stat st;
     time_t now;
     
@@ -252,11 +252,11 @@ static int lock_common(const char * filename, int fd, short locktype)
       goto unlock;
     }
 
-    fd = open(lockfilename, O_WRONLY|O_EXCL|O_CREAT, 0);
-    if (fd >= 0) {
+    fd2 = open(lockfilename, O_WRONLY|O_EXCL|O_CREAT, 0);
+    if (fd2 >= 0) {
       /* defeat lock checking programs which test pid */
-      write(fd, "0", 2);
-      close(fd);
+      write(fd2, "0", 2);
+      close(fd2);
       break;
     }
     
