@@ -1,10 +1,9 @@
-#include "mailsasl.h"
-
-#ifndef CONFIG_H
-#define CONFIG_H
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
 #endif
 
+#include "mailsasl.h"
+
 #ifdef USE_SASL
 
 #ifdef LIBETPAN_REENTRANT
@@ -48,7 +47,9 @@ void mailsasl_unref(void)
 #endif
   sasl_use_count --;
   if (sasl_use_count == 0) {
+#if 0 /* workaround libsasl bug */
     sasl_done();
+#endif
   }
 #ifdef LIBETPAN_REENTRANT
   pthread_mutex_unlock(&sasl_lock);
