@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailstream_ssl.c,v 1.57 2007/07/30 09:35:26 colinleroy Exp $
+ * $Id: mailstream_ssl.c,v 1.63 2008/02/17 13:13:26 hoa Exp $
  */
 
 /*
@@ -45,6 +45,7 @@
 #endif
 
 #include "mailstream_ssl.h"
+#include "mailstream_ssl_private.h"
 
 #ifdef HAVE_UNISTD_H
 #	include <unistd.h>
@@ -61,7 +62,9 @@
   these 3 headers MUST be included before <sys/select.h>
   to insure compatibility with Mac OS X (this is true for 10.2)
 */
-#ifndef _MSC_VER
+#ifdef WIN32
+#	include <win_etpan.h>
+#else
 #	include <sys/time.h>
 #	include <sys/types.h>
 #	ifdef HAVE_SYS_SELECT_H
@@ -100,6 +103,7 @@ struct mailstream_ssl_data {
 struct mailstream_ssl_data {
   int fd;
   gnutls_session session;
+  gnutls_certificate_credentials_t xcred;
   struct mailstream_cancel * cancel;
 };
 #endif
@@ -107,15 +111,16 @@ struct mailstream_ssl_data {
 
 #ifdef USE_SSL
 #ifdef LIBETPAN_REENTRANT
-#	ifdef WIN32
-#		define MUTEX_LOCK(x) {if (!_init_lock) {_init_lock=1; InitializeCriticalSection( x);} EnterCriticalSection(x);}
-#		define MUTEX_UNLOCK(x) {if (!_init_lock) {_init_lock=1; InitializeCriticalSection( x);} LeaveCriticalSection(x); }
-		static CRITICAL_SECTION ssl_lock;
-		static int _init_lock = 0;
-#	else
+#	if HAVE_PTHREAD_H
 #		define MUTEX_LOCK(x) pthread_mutex_lock(x)
 #		define MUTEX_UNLOCK(x) pthread_mutex_unlock(x)
 		static pthread_mutex_t ssl_lock = PTHREAD_MUTEX_INITIALIZER;
+#	elif (defined WIN32)
+#		define MUTEX_LOCK(x) EnterCriticalSection(x);
+#		define MUTEX_UNLOCK(x) LeaveCriticalSection(x);
+		static CRITICAL_SECTION ssl_lock;
+#	else
+#		error "What are your threads?"
 #	endif
 #else
 #	define MUTEX_LOCK(x)
@@ -125,6 +130,13 @@ static int gnutls_init_done = 0;
 static int openssl_init_done = 0;
 #endif
 
+void mailstream_ssl_init_lock(void)
+{
+#if !defined (HAVE_PTHREAD_H) && defined (WIN32)
+  InitializeCriticalSection(&ssl_lock);
+#endif
+}
+
 void mailstream_gnutls_init_not_required(void)
 {
 #ifdef USE_SSL
@@ -186,7 +198,7 @@ static inline int mailstream_prepare_fd(int fd)
 }
 #endif
 
-static int wait_SSL_connect(int s, int read)
+static int wait_SSL_connect(int s, int want_read)
 {
   fd_set fds;
   struct timeval timeout;
@@ -196,7 +208,7 @@ static int wait_SSL_connect(int s, int read)
   FD_SET(s, &fds);
   timeout = mailstream_network_delay;
   /* TODO: how to cancel this ? */
-  if (read)
+  if (want_read)
     r = select(s + 1, &fds, NULL, NULL, &timeout);
   else
     r = select(s + 1, NULL, &fds, NULL, &timeout);
@@ -370,9 +382,12 @@ static struct mailstream_ssl_data * ssl_data_new(int fd, void (* callback)(struc
   gnutls_mac_set_priority (session, mac_prio);
 
   gnutls_credentials_set(session, GNUTLS_CRD_CERTIFICATE, xcred);
-
+  gnutls_dh_set_prime_bits(session, 512);
   gnutls_transport_set_ptr(session, (gnutls_transport_ptr) fd);
 
+  /* lower limits on server key length restriction */
+  gnutls_dh_set_prime_bits(session, 512);
+  
   do {
     r = gnutls_handshake(session);
   } while (r == GNUTLS_E_AGAIN || r == GNUTLS_E_INTERRUPTED);
@@ -395,6 +410,7 @@ static struct mailstream_ssl_data * ssl_data_new(int fd, void (* callback)(struc
   
   ssl_data->fd = fd;
   ssl_data->session = session;
+  ssl_data->xcred = xcred;
   ssl_data->cancel = cancel;
   
   return ssl_data;
@@ -402,6 +418,7 @@ static struct mailstream_ssl_data * ssl_data_new(int fd, void (* callback)(struc
  free_cancel:
   mailstream_cancel_free(cancel);
  free_ssl_conn:
+  gnutls_certificate_free_credentials(xcred);
   gnutls_deinit(session);
  err:
   return NULL;
@@ -431,6 +448,7 @@ static void  ssl_data_close(struct mailstream_ssl_data * ssl_data)
 #else
 static void  ssl_data_close(struct mailstream_ssl_data * ssl_data)
 {
+  gnutls_certificate_free_credentials(ssl_data->xcred);
   gnutls_deinit(ssl_data->session);
   ssl_data->session = NULL;
   close(ssl_data->fd);
