@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mmapstring.c,v 1.22 2006/06/26 11:50:26 hoa Exp $
+ * $Id: mmapstring.c,v 1.24 2007/12/15 09:28:08 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -38,24 +38,24 @@
 #endif
 
 #include "mmapstring.h"
+#include "mmapstring_private.h"
 
 #include "chash.h"
 
 #include <stdlib.h>
-#ifdef _MSC_VER
+#ifdef WIN32
 #	include "win_etpan.h"
 #else
 #	include <unistd.h>
 #	include <sys/mman.h>
 #endif
 #include <string.h>
-#ifdef LIBETPAN_REENTRANT
-#	ifndef WIN32
-#		include <pthread.h>
-#	endif
-#endif
-
 #include "libetpan-config.h"
+#ifdef LIBETPAN_REENTRANT
+#ifdef HAVE_PTHREAD_H
+#include <pthread.h>
+#endif
+#endif
 
 #define MMAPSTRING_MAX(a, b) ((a) > (b) ? (a) : (b))
 #define MMAPSTRING_MIN(a, b) ((a) < (b) ? (a) : (b))
@@ -69,32 +69,17 @@ static char tmpdir[PATH_MAX] = DEFAULT_TMP_PATH;
 static size_t mmap_string_ceil = MMAP_STRING_DEFAULT_CEIL;
 
 /* MMAPString references */
-
 #ifdef LIBETPAN_REENTRANT
-#	ifdef WIN32
-
-		static	CRITICAL_SECTION mmapstring_lock ;
-		static  CRITICAL_SECTION* _get_critical() {
-					InitializeCriticalSection(&mmapstring_lock);
-					return &mmapstring_lock;
-				}
-		static	int	_lock_initialized = 0;
-		static void __mutex_lock(CRITICAL_SECTION* section) {
-			if (!_lock_initialized)
-				InitializeCriticalSection(section);
-		    EnterCriticalSection( section);
-		}
-		static void __mutex_unlock(CRITICAL_SECTION* section) {
-			if (!_lock_initialized)
-				InitializeCriticalSection(section);
-			LeaveCriticalSection( section);
-		}
-#		define MUTEX_LOCK(x) __mutex_lock(x)
-#		define MUTEX_UNLOCK(x) __mutex_unlock(x)
-#	else
+#	if HAVE_PTHREAD_H
 		static pthread_mutex_t mmapstring_lock = PTHREAD_MUTEX_INITIALIZER;
 #		define MUTEX_LOCK(x) pthread_mutex_lock(x)
 #		define MUTEX_UNLOCK(x) pthread_mutex_unlock(x)
+#	elif (defined WIN32)
+		static	CRITICAL_SECTION mmapstring_lock ;
+#		define MUTEX_LOCK(x) EnterCriticalSection(x)
+#		define MUTEX_UNLOCK(x) LeaveCriticalSection(x)
+#	else
+#		error "What are your threads?"
 #	endif
 #else
 #	define MUTEX_LOCK(x) 
@@ -102,6 +87,13 @@ static size_t mmap_string_ceil = MMAP_STRING_DEFAULT_CEIL;
 #endif
 static chash * mmapstring_hashtable = NULL;
 
+void mmapstring_init_lock(void)
+{
+#if !defined (HAVE_PTHREAD_H) && defined (WIN32)
+  InitializeCriticalSection(&mmapstring_lock);
+#endif
+}
+
 static void mmapstring_hashtable_init(void)
 {
   mmapstring_hashtable = chash_new(CHASH_DEFAULTSIZE, CHASH_COPYKEY);
