@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_cached_message.c,v 1.26 2006/11/12 15:15:58 hoa Exp $
+ * $Id: imapdriver_cached_message.c,v 1.29 2008/02/17 13:13:26 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -40,6 +40,7 @@
 #include "imapdriver_cached_message.h"
 
 #include "imapdriver_tools.h"
+#include "imapdriver_tools_private.h"
 #include "imapdriver_message.h"
 #include "imapdriver_cached.h"
 #include "imapdriver_types.h"
@@ -106,7 +107,6 @@ static int imap_get_flags(mailmessage * msg_info,
 			  struct mail_flags ** result);
 
 static mailmessage_driver local_imap_cached_message_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* msg_name */ "imap-cached",
 
   /* msg_initialize */ imap_initialize,
@@ -128,31 +128,7 @@ static mailmessage_driver local_imap_cached_message_driver = {
   /* msg_fetch_section_body */ imap_fetch_section_body,
   /* msg_fetch_envelope */ imap_fetch_envelope,
 
-  /* msg_get_flags */ imap_get_flags,
-#else
-  .msg_name = "imap-cached",
-
-  .msg_initialize = imap_initialize,
-  .msg_uninitialize = imap_uninitialize,
-
-  .msg_flush = imap_flush,
-  .msg_check = imap_check,
-
-  .msg_fetch_result_free = imap_fetch_result_free,
-
-  .msg_fetch = imap_fetch,
-  .msg_fetch_header = imap_fetch_header,
-  .msg_fetch_body = imap_fetch_body,
-  .msg_fetch_size = imap_fetch_size,
-  .msg_get_bodystructure = imap_get_bodystructure,
-  .msg_fetch_section = imap_fetch_section,
-  .msg_fetch_section_header = imap_fetch_section_header,
-  .msg_fetch_section_mime = imap_fetch_section_mime,
-  .msg_fetch_section_body = imap_fetch_section_body,
-  .msg_fetch_envelope = imap_fetch_envelope,
-
-  .msg_get_flags = imap_get_flags,
-#endif
+  /* msg_get_flags */ imap_get_flags
 };
 
 mailmessage_driver * imap_cached_message_driver =
@@ -728,7 +704,7 @@ static int imap_fetch_envelope(mailmessage * msg_info,
 
   r = mail_cache_db_open_lock(filename, &cache_db);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto err;
   }
 
