@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_tools.c,v 1.25 2007/05/19 21:19:50 hoa Exp $
+ * $Id: imapdriver_tools.c,v 1.30 2008/02/20 22:15:50 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -38,6 +38,7 @@
 #endif
 
 #include "imapdriver_tools.h"
+#include "imapdriver_tools_private.h"
 
 #include "maildriver.h"
 
@@ -83,10 +84,6 @@ cached_session_get_imap_session(mailsession * session)
   return cached_session_get_ancestor_data(session)->imap_session;
 }
 
-static int imap_flags_to_flags(struct mailimap_msg_att_dynamic * att_dyn,
-			       struct mail_flags ** result);
-
-
 int imap_error_to_mail_error(int error)
 {
   switch (error) {
@@ -277,8 +274,8 @@ int imap_list_to_list(clist * imap_list, struct mail_list ** result)
 }
 
 int
-section_to_imap_section(struct mailmime_section * section, int type,
-			struct mailimap_section ** result)
+imap_section_to_imap_section(struct mailmime_section * section, int type,
+    struct mailimap_section ** result)
 {
   struct mailimap_section_part * section_part;
   struct mailimap_section * imap_section;
@@ -393,7 +390,7 @@ imap_body_media_basic_to_content_type(struct mailimap_media_basic *
 
   case MAILIMAP_MEDIA_BASIC_AUDIO:
     mime_type_type = MAILMIME_TYPE_DISCRETE_TYPE;
-    discrete_type_type = MAILMIME_DISCRETE_TYPE_APPLICATION;
+    discrete_type_type = MAILMIME_DISCRETE_TYPE_AUDIO;
     break;
 
   case MAILIMAP_MEDIA_BASIC_IMAGE:
@@ -1368,10 +1365,17 @@ imap_body_type_mpart_to_body(struct mailimap_body_type_mpart *
   int res;
   uint32_t mime_size;
 
-  r = imap_body_fields_to_mime_fields(NULL,
-      type_mpart->bd_ext_mpart->bd_disposition,
-      type_mpart->bd_ext_mpart->bd_language,
-      &mime_fields, &mime_size);
+  if (type_mpart->bd_ext_mpart == NULL) {
+    mime_fields = mailmime_fields_new_empty();
+    mime_size = 0;
+    r = MAIL_NO_ERROR;
+  }
+  else {
+    r = imap_body_fields_to_mime_fields(NULL,
+        type_mpart->bd_ext_mpart->bd_disposition,
+        type_mpart->bd_ext_mpart->bd_language,
+        &mime_fields, &mime_size);
+  }
   if (r != MAIL_NO_ERROR) {
     res = r;
     goto err;
@@ -1393,9 +1397,16 @@ imap_body_type_mpart_to_body(struct mailimap_body_type_mpart *
     goto free_fields;
   }
 
-  r = imap_body_parameter_to_content(type_mpart->bd_ext_mpart->bd_parameter,
-				     type_mpart->bd_media_subtype,
-				     mime_type, &content_type);
+  if (type_mpart->bd_ext_mpart == NULL) {
+    r = imap_body_parameter_to_content(NULL,
+        type_mpart->bd_media_subtype,
+        mime_type, &content_type);
+  }
+  else {
+    r = imap_body_parameter_to_content(type_mpart->bd_ext_mpart->bd_parameter,
+        type_mpart->bd_media_subtype,
+        mime_type, &content_type);
+  }
   if (r != MAIL_NO_ERROR) {
     mailmime_type_free(mime_type);
     res = r;
@@ -1508,7 +1519,12 @@ int imap_address_to_mailbox(struct mailimap_address * imap_addr,
   }
 
   if (imap_addr->ad_host_name == NULL) {
-    addr = strdup(imap_addr->ad_mailbox_name);
+    if (imap_addr->ad_mailbox_name == NULL) {
+      addr = strdup("");
+    }
+    else {
+      addr = strdup(imap_addr->ad_mailbox_name);
+    }
     if (addr == NULL) {
       res = MAIL_ERROR_MEMORY;
       goto free_name;
@@ -2853,8 +2869,8 @@ int mail_search_to_imap_search(struct mail_search_key * key,
 #endif
 
 
-int msg_list_to_imap_set(clist * msg_list,
-			 struct mailimap_set ** result)
+int imap_msg_list_to_imap_set(clist * msg_list,
+    struct mailimap_set ** result)
 {
   struct mailimap_set * imap_set;
   clistiter * cur;
@@ -2940,9 +2956,9 @@ int msg_list_to_imap_set(clist * msg_list,
 
 
 static int
-uid_list_to_env_list(clist * fetch_result,
-		     struct mailmessage_list ** result,
-		     mailsession * session, mailmessage_driver * driver)
+imap_uid_list_to_env_list(mailsession * session, mailmessage_driver * driver,
+    clist * fetch_result,
+    struct mailmessage_list ** result)
 {
   clistiter * cur;
   struct mailmessage_list * env_list;
@@ -3042,8 +3058,8 @@ uid_list_to_env_list(clist * fetch_result,
   MAILIMAP_FLAG_EXTENSION
 */
 
-static int imap_flags_to_flags(struct mailimap_msg_att_dynamic * att_dyn,
-			       struct mail_flags ** result)
+int imap_flags_to_flags(struct mailimap_msg_att_dynamic * att_dyn,
+    struct mail_flags ** result)
 {
   struct mail_flags * flags;
   clist * flag_list;
@@ -3306,7 +3322,7 @@ static int flags_to_imap_flags(struct mail_flags * flags,
 
 
 static int
-imap_fetch_result_to_flags(clist * fetch_result, uint32_t index,
+imap_fetch_result_to_flags(clist * fetch_result, uint32_t indx,
 			   struct mail_flags ** result)
 {
   clistiter * cur;
@@ -3345,7 +3361,7 @@ imap_fetch_result_to_flags(clist * fetch_result, uint32_t index,
     }
 
     if (uid != 0) {
-      if (uid == index) {
+      if (uid == indx) {
 	struct mail_flags * flags;
 	
 	if (att_dyn != NULL) {
@@ -3365,7 +3381,7 @@ imap_fetch_result_to_flags(clist * fetch_result, uint32_t index,
 
 
 int imap_fetch_flags(mailimap * imap,
-		     uint32_t index, struct mail_flags ** result)
+		     uint32_t indx, struct mail_flags ** result)
 {
   struct mailimap_fetch_att * fetch_att;
   struct mailimap_fetch_type * fetch_type;
@@ -3407,7 +3423,7 @@ int imap_fetch_flags(mailimap * imap,
     goto free_fetch_type;
   }
 
-  set = mailimap_set_new_single(index);
+  set = mailimap_set_new_single(indx);
   if (set == NULL) {
     res = MAIL_ERROR_MEMORY;
     goto free_fetch_type;
@@ -3426,7 +3442,7 @@ int imap_fetch_flags(mailimap * imap,
   }
   
   flags = NULL;
-  r = imap_fetch_result_to_flags(fetch_result, index, &flags);
+  r = imap_fetch_result_to_flags(fetch_result, indx, &flags);
   mailimap_fetch_list_free(fetch_result);
 
   if (r != MAIL_NO_ERROR) {
@@ -3549,7 +3565,7 @@ int imap_get_messages_list(mailimap * imap,
   }
 
   env_list = NULL;
-  r = uid_list_to_env_list(fetch_result, &env_list, session, driver);
+  r = imap_uid_list_to_env_list(session, driver, fetch_result, &env_list);
   mailimap_fetch_list_free(fetch_result);
 
   * result = env_list;
@@ -3646,4 +3662,3 @@ imapdriver_write_cached_envelope(struct mail_cache_db * cache_db,
 err:
   return res;
 }
-
