@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailstorage_tools.c,v 1.22 2007/06/30 12:58:21 hoa Exp $
+ * $Id: mailstorage_tools.c,v 1.23 2007/10/27 10:08:25 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -43,7 +43,9 @@
 
 #include <sys/types.h>
 #include <stdlib.h>
-#ifndef _MSC_VER
+#ifdef WIN32
+#	include "win_etpan.h"
+#else
 #	include <netdb.h>
 #	include <netinet/in.h>
 #	include <sys/socket.h>
