@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailprivacy.c,v 1.7 2006/05/22 13:39:40 hoa Exp $
+ * $Id: mailprivacy.c,v 1.8 2007/10/27 10:08:25 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -44,7 +44,11 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <sys/mman.h>
+#ifdef WIN32
+#	include "win_etpan.h"
+#else
+#	include <sys/mman.h>
+#endif
 #include <stdlib.h>
 #include <string.h>
 #include "mailprivacy_tools.h"
@@ -66,11 +70,13 @@ static int check_tmp_dir(char * tmp_dir)
   r = stat(tmp_dir, &stat_info);
   if (r < 0)
     return MAIL_ERROR_FILE;
- 
+
+#ifndef WIN32 
   /* check if the directory belongs to the user */
   if (stat_info.st_uid != getuid())
     return MAIL_ERROR_INVAL;
-  
+#endif
+
   if ((stat_info.st_mode & 00777) != 0700) {
     r = chmod(tmp_dir, 0700);
     if (r < 0)
