@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailprivacy_gnupg.c,v 1.10 2006/06/26 11:50:27 hoa Exp $
+ * $Id: mailprivacy_gnupg.c,v 1.13 2008/02/17 13:13:27 hoa Exp $
  */
 
 /* passphrase is needed when private key is needed
@@ -50,11 +50,16 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <sys/mman.h>
+#ifdef WIN32
+#	include "win_etpan.h"
+#else
+#	include <sys/mman.h>
+#	include <sys/wait.h>
+#endif
 #include <string.h>
-#include <sys/wait.h>
 #include <stdlib.h>
 #include "mailprivacy_tools.h"
+#include "mailprivacy_tools_private.h"
 #include <libetpan/mailmime.h>
 #include <libetpan/libetpan-config.h>
 #ifdef LIBETPAN_REENTRANT
@@ -62,7 +67,6 @@
 #endif
 #include <ctype.h>
 
-
 enum {
   NO_ERROR_PGP = 0,
   ERROR_PGP_CHECK,
@@ -77,91 +81,35 @@ static char * get_passphrase(struct mailprivacy * privacy,
     char * user_id);
 static int get_userid(char * filename, char * username, size_t length);
 
+
 static int gpg_command_passphrase(struct mailprivacy * privacy,
     struct mailmessage * msg,
     char * command, char * userid,
     char * stdoutfile, char * stderrfile)
 {
-  pid_t pid;
-  int passphrase_input[2];
-  int fd_err;
-  int fd_out;
-  int r;
   char * passphrase;
   int bad_passphrase;
   int res;
-  
+  int r;
+
   bad_passphrase = 0;
   
   passphrase = NULL;
   if (userid != NULL)
     passphrase = get_passphrase(privacy, userid);
   
-  fd_out = open(stdoutfile, O_RDWR | O_CREAT | O_TRUNC, 0600);
-  if (fd_out < 0) {
-    res = ERROR_PGP_FILE;
-    goto err;
-  }
-  
-  fd_err = open(stderrfile, O_RDWR | O_CREAT | O_TRUNC, 0600);
-  if (fd_err < 0) {
-    res = ERROR_PGP_FILE;
-    goto close_out;
-  }
-  
-  r = pipe(passphrase_input);
-  if (r < 0) {
-    res = ERROR_PGP_FILE;
-    goto close_err;
-  }
-  
-  pid = fork();
-  switch (pid) {
-  case -1:
-    return ERROR_PGP_COMMAND;
-    
-  case 0:
-    /* child */
-    {
-      int status;
-      
-      /* close unneeded fd */
-      close(passphrase_input[1]);
-      
-      dup2(passphrase_input[0], 0);
-      close(passphrase_input[0]);
-      dup2(fd_out, 1);
-      close(fd_out);
-      dup2(fd_err, 2);
-      close(fd_err);
-      
-      status = system(command);
-      
-      exit(WEXITSTATUS(status));
+  res = mailprivacy_spawn_and_wait(command, passphrase, stdoutfile, stderrfile,
+      &bad_passphrase);
+  if (res != NO_ERROR_PASSPHRASE) {
+    switch (res) {
+    case ERROR_PASSPHRASE_COMMAND:
+      return ERROR_PGP_COMMAND;
+    case ERROR_PASSPHRASE_FILE:
+      return ERROR_PGP_FILE;
+    default:
+      return ERROR_PGP_COMMAND;
     }
-    break;
-    
-  default:
-    /* parent */
-    {
-      int status;
-      
-      /* close unneeded fd */
-      close(fd_err);
-      close(fd_out);
-      close(passphrase_input[0]);
-      
-      if (passphrase != NULL) {
-        write(passphrase_input[1], passphrase, strlen(passphrase));
-      }
-      close(passphrase_input[1]);
-      
-      waitpid(pid, &status, 0);
-      
-      if (WEXITSTATUS(status) != 0)
-        bad_passphrase = 1;
-    }
-    break;
+    return res;
   }
   
   if (bad_passphrase && (userid == NULL)) {
@@ -195,13 +143,6 @@ static int gpg_command_passphrase(struct mailprivacy * privacy,
   }
   
   return NO_ERROR_PGP;
-  
- close_err:
-  close(fd_err);
- close_out:
-  close(fd_out);
- err:
-  return res;
 }
 
 static int pgp_is_encrypted(struct mailmime * mime)
@@ -2813,13 +2754,12 @@ static int pgp_armor_sign_encrypt(struct mailprivacy * privacy,
   return res;
 }
 
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
 static struct mailprivacy_encryption pgp_encryption_tab[] = {
   /* PGP signed part */
   {
     /* name */ "signed",
     /* description */ "PGP signed part",
-    /* encrypt */ pgp_sign_mime,
+    /* encrypt */ pgp_sign_mime
   },
   
   /* pgp encrypted part */
@@ -2827,7 +2767,7 @@ static struct mailprivacy_encryption pgp_encryption_tab[] = {
   {
     /* name */ "encrypted",
     /* description */ "PGP encrypted part",
-    /* encrypt */ pgp_encrypt_mime,
+    /* encrypt */ pgp_encrypt_mime
   },
   
   /* PGP signed & encrypted part */
@@ -2835,7 +2775,7 @@ static struct mailprivacy_encryption pgp_encryption_tab[] = {
   {
     /* name */ "signed-encrypted",
     /* description */ "PGP signed & encrypted part",
-    /* encrypt */ pgp_sign_encrypt_mime,
+    /* encrypt */ pgp_sign_encrypt_mime
   },
 
   /* PGP clear signed part */
@@ -2843,7 +2783,7 @@ static struct mailprivacy_encryption pgp_encryption_tab[] = {
   {
     /* name */ "clear-signed",
     /* description */ "PGP clear signed part",
-    /* encrypt */ pgp_clear_sign,
+    /* encrypt */ pgp_clear_sign
   },
 
   /* PGP armor encrypted part */
@@ -2851,7 +2791,7 @@ static struct mailprivacy_encryption pgp_encryption_tab[] = {
   {
     /* name */ "encrypted-armor",
     /* description */ "PGP ASCII armor encrypted part",
-    /* encrypt */ pgp_armor_encrypt,
+    /* encrypt */ pgp_armor_encrypt
   },
 
   /* PGP armor signed & encrypted part */
@@ -2859,61 +2799,10 @@ static struct mailprivacy_encryption pgp_encryption_tab[] = {
   {
     /* name */ "signed-encrypted-armor",
     /* description */ "PGP ASCII armor signed & encrypted part",
-    /* encrypt */ pgp_armor_sign_encrypt,
-  },
+    /* encrypt */ pgp_armor_sign_encrypt
+  }
 };
-#else
-static struct mailprivacy_encryption pgp_encryption_tab[] = {
-  /* PGP signed part */
-  {
-    .name = "signed",
-    .description = "PGP signed part",
-    .encrypt = pgp_sign_mime,
-  },
-  
-  /* pgp encrypted part */
-  
-  {
-    .name = "encrypted",
-    .description = "PGP encrypted part",
-    .encrypt = pgp_encrypt_mime,
-  },
-  
-  /* PGP signed & encrypted part */
-  
-  {
-    .name = "signed-encrypted",
-    .description = "PGP signed & encrypted part",
-    .encrypt = pgp_sign_encrypt_mime,
-  },
 
-  /* PGP clear signed part */
-  
-  {
-    .name = "clear-signed",
-    .description = "PGP clear signed part",
-    .encrypt = pgp_clear_sign,
-  },
-
-  /* PGP armor encrypted part */
-  
-  {
-    .name = "encrypted-armor",
-    .description = "PGP ASCII armor encrypted part",
-    .encrypt = pgp_armor_encrypt,
-  },
-
-  /* PGP armor signed & encrypted part */
-  
-  {
-    .name = "signed-encrypted-armor",
-    .description = "PGP ASCII armor signed & encrypted part",
-    .encrypt = pgp_armor_sign_encrypt,
-  },
-};
-#endif
-
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
 static struct mailprivacy_protocol pgp_protocol = {
   /* name */ "pgp",
   /* description */ "OpenPGP",
@@ -2924,22 +2813,8 @@ static struct mailprivacy_protocol pgp_protocol = {
   /* encryption_count */
   (sizeof(pgp_encryption_tab) / sizeof(pgp_encryption_tab[0])),
   
-  /* encryption_tab */ pgp_encryption_tab,
+  /* encryption_tab */ pgp_encryption_tab
 };
-#else
-static struct mailprivacy_protocol pgp_protocol = {
-  .name = "pgp",
-  .description = "OpenPGP",
-  
-  .is_encrypted = pgp_test_encrypted,
-  .decrypt = pgp_handler,
-  
-  .encryption_count =
-  (sizeof(pgp_encryption_tab) / sizeof(pgp_encryption_tab[0])),
-  
-  .encryption_tab = pgp_encryption_tab,
-};
-#endif
 
 int mailprivacy_gnupg_init(struct mailprivacy * privacy)
 {
