@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailprivacy_smime.c,v 1.15 2006/08/29 22:27:35 hoa Exp $
+ * $Id: mailprivacy_smime.c,v 1.18 2008/02/17 13:13:27 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -39,17 +39,23 @@
 
 #include "mailprivacy_smime.h"
 #include <string.h>
+#ifdef WIN32
+#	include "win_etpan.h"
+#	define WEXITSTATUS(r) (r)
+#else
+#	include <sys/mman.h>
+#	include <sys/wait.h>
+#	include <dirent.h>
+#endif
 #include <pthread.h>
-#include <sys/wait.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <sys/mman.h>
 #include "mailprivacy_tools.h"
+#include "mailprivacy_tools_private.h"
 #include "mailprivacy.h"
 #include <stdlib.h>
-#include <dirent.h>
 #include <stdio.h>
 #include <ctype.h>
 #include <libetpan/libetpan-config.h>
@@ -65,8 +71,6 @@ static int smime_command_passphrase(struct mailprivacy * privacy,
     char * command,
     char * passphrase,
     char * stdoutfile, char * stderrfile);
-static char * get_passphrase(struct mailprivacy * privacy,
-    char * user_id);
 static int mailprivacy_smime_add_encryption_id(struct mailprivacy * privacy,
     mailmessage * msg, char * encryption_id);
 
@@ -1153,13 +1157,12 @@ static int smime_sign_encrypt(struct mailprivacy * privacy,
 }
 
 
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
 static struct mailprivacy_encryption smime_encryption_tab[] = {
   /* S/MIME signed part */
   {
     /* name */ "signed",
     /* description */ "S/MIME signed part",
-    /* encrypt */ smime_sign,
+    /* encrypt */ smime_sign
   },
   
   /* S/MIME encrypted part */
@@ -1167,7 +1170,7 @@ static struct mailprivacy_encryption smime_encryption_tab[] = {
   {
     /* name */ "encrypted",
     /* description */ "S/MIME encrypted part",
-    /* encrypt */ smime_encrypt,
+    /* encrypt */ smime_encrypt
   },
 
   /* S/MIME signed & encrypted part */
@@ -1175,37 +1178,10 @@ static struct mailprivacy_encryption smime_encryption_tab[] = {
   {
     /* name */ "signed-encrypted",
     /* description */ "S/MIME signed & encrypted part",
-    /* encrypt */ smime_sign_encrypt,
-  },
+    /* encrypt */ smime_sign_encrypt
+  }
 };
-#else
-static struct mailprivacy_encryption smime_encryption_tab[] = {
-  /* S/MIME signed part */
-  {
-    .name = "signed",
-    .description = "S/MIME signed part",
-    .encrypt = smime_sign,
-  },
-  
-  /* S/MIME encrypted part */
-  
-  {
-    .name = "encrypted",
-    .description = "S/MIME encrypted part",
-    .encrypt = smime_encrypt,
-  },
 
-  /* S/MIME signed & encrypted part */
-  
-  {
-    .name = "signed-encrypted",
-    .description = "S/MIME signed & encrypted part",
-    .encrypt = smime_sign_encrypt,
-  },
-};
-#endif
-
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
 static struct mailprivacy_protocol smime_protocol = {
   /* name */ "smime",
   /* description */ "S/MIME",
@@ -1216,22 +1192,8 @@ static struct mailprivacy_protocol smime_protocol = {
   /* encryption_count */
   (sizeof(smime_encryption_tab) / sizeof(smime_encryption_tab[0])),
   
-  /* encryption_tab */ smime_encryption_tab,
+  /* encryption_tab */ smime_encryption_tab
 };
-#else
-static struct mailprivacy_protocol smime_protocol = {
-  .name = "smime",
-  .description = "S/MIME",
-  
-  .is_encrypted = smime_test_encrypted,
-  .decrypt = smime_handler,
-  
-  .encryption_count =
-  (sizeof(smime_encryption_tab) / sizeof(smime_encryption_tab[0])),
-  
-  .encryption_tab = smime_encryption_tab,
-};
-#endif
 
 int mailprivacy_smime_init(struct mailprivacy * privacy)
 {
@@ -1686,98 +1648,39 @@ void mailprivacy_smime_set_private_keys_dir(struct mailprivacy * privacy,
   - then, ask passphrase for all private keys
 */
 
+static char * get_passphrase(struct mailprivacy * privacy,
+    char * user_id);
+
 static int smime_command_passphrase(struct mailprivacy * privacy,
     struct mailmessage * msg,
     char * command,
     char * userid,
     char * stdoutfile, char * stderrfile)
 {
-  pid_t pid;
-  int passphrase_input[2];
-  int fd_err;
-  int fd_out;
-  int r;
   char * passphrase;
-  int bad_passphrase;
   int res;
-  
+  int bad_passphrase;
+
   bad_passphrase = 0;
   
   passphrase = NULL;
   if (userid != NULL)
     passphrase = get_passphrase(privacy, userid);
   
-  fd_out = open(stdoutfile, O_RDWR | O_CREAT | O_TRUNC, 0600);
-  if (fd_out < 0) {
-    res = ERROR_SMIME_FILE;
-    goto err;
-  }
-  
-  fd_err = open(stderrfile, O_RDWR | O_CREAT | O_TRUNC, 0600);
-  if (fd_err < 0) {
-    res = ERROR_SMIME_FILE;
-    goto close_out;
-  }
-  
-  r = pipe(passphrase_input);
-  if (r < 0) {
-    res = ERROR_SMIME_FILE;
-    goto close_err;
-  }
-  
-  pid = fork();
-  switch (pid) {
-  case -1:
-    return ERROR_SMIME_COMMAND;
-    
-  case 0:
-    /* child */
-    {
-      int status;
-      
-      /* close unneeded fd */
-      close(passphrase_input[1]);
-      
-      dup2(passphrase_input[0], 0);
-      close(passphrase_input[0]);
-      dup2(fd_out, 1);
-      close(fd_out);
-      dup2(fd_err, 2);
-      close(fd_err);
-      
-      status = system(command);
-      
-      exit(WEXITSTATUS(status));
+  res = mailprivacy_spawn_and_wait(command, passphrase, stdoutfile, stderrfile,
+		       &bad_passphrase);
+  if (res != NO_ERROR_PASSPHRASE) {
+    switch (res) {
+    case ERROR_PASSPHRASE_COMMAND:
+      return ERROR_SMIME_COMMAND;
+    case ERROR_PASSPHRASE_FILE:
+      return ERROR_SMIME_FILE;
+    default:
+      return ERROR_SMIME_COMMAND;
     }
-    break;
-    
-  default:
-    /* parent */
-    {
-      int status;
-      
-      /* close unneeded fd */
-      close(fd_err);
-      close(fd_out);
-      close(passphrase_input[0]);
-      
-      if ((passphrase != NULL) && (strlen(passphrase) > 0)) {
-        write(passphrase_input[1], passphrase, strlen(passphrase));
-      }
-      else {
-        /* dummy password */
-        write(passphrase_input[1], "*dummy*", 7);
-      }
-      close(passphrase_input[1]);
-      
-      waitpid(pid, &status, 0);
-      
-      if (WEXITSTATUS(status) != 0)
-        bad_passphrase = 1;
-    }
-    break;
+    return res;
   }
-  
+
   if (bad_passphrase) {
     if (userid != NULL) {
       mailprivacy_smime_add_encryption_id(privacy, msg, userid);
@@ -1788,13 +1691,6 @@ static int smime_command_passphrase(struct mailprivacy * privacy,
   }
   
   return NO_ERROR_SMIME;
-  
- close_err:
-  close(fd_err);
- close_out:
-  close(fd_out);
- err:
-  return res;
 }
 
 
