@@ -83,7 +83,7 @@ LIBETPAN_EXPORT
 int
 mailimap_extension_data_parse(int calling_parser,
         mailstream * fd, MMAPString * buffer,
-        size_t * index, struct mailimap_extension_data ** result,
+        size_t * indx, struct mailimap_extension_data ** result,
         size_t progr_rate,
         progress_function * progr_fun)
 {
@@ -95,7 +95,7 @@ mailimap_extension_data_parse(int calling_parser,
     struct mailimap_extension_api * ext;
     
     ext = internal_extension_list[i];
-    r = ext->ext_parser(calling_parser, fd, buffer, index, result,
+    r = ext->ext_parser(calling_parser, fd, buffer, indx, result,
         progr_rate, progr_fun);
     if (r != MAILIMAP_ERROR_PARSE)
       return r;
@@ -109,7 +109,7 @@ mailimap_extension_data_parse(int calling_parser,
     struct mailimap_extension_api * ext;
     
     ext = clist_content(cur);
-    r = ext->ext_parser(calling_parser, fd, buffer, index, result,
+    r = ext->ext_parser(calling_parser, fd, buffer, indx, result,
         progr_rate, progr_fun);
     if (r != MAILIMAP_ERROR_PARSE)
       return r;
