@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap_types_helper.c,v 1.12 2006/06/26 11:50:27 hoa Exp $
+ * $Id: mailimap_types_helper.c,v 1.13 2008/02/20 22:15:52 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -54,9 +54,9 @@
 
 
 
-struct mailimap_set_item * mailimap_set_item_new_single(uint32_t index)
+struct mailimap_set_item * mailimap_set_item_new_single(uint32_t indx)
 {
-  return mailimap_set_item_new(index, index);
+  return mailimap_set_item_new(indx, indx);
 }
 
 struct mailimap_set *
@@ -103,9 +103,9 @@ struct mailimap_set * mailimap_set_new_interval(uint32_t first, uint32_t last)
   return set;
 }
 
-struct mailimap_set * mailimap_set_new_single(uint32_t index)
+struct mailimap_set * mailimap_set_new_single(uint32_t indx)
 {
-  return mailimap_set_new_interval(index, index);
+  return mailimap_set_new_interval(indx, indx);
 }
 
 
@@ -152,9 +152,9 @@ int mailimap_set_add_interval(struct mailimap_set * set,
 }
 
 int mailimap_set_add_single(struct mailimap_set * set,
-           		    uint32_t index)
+           		    uint32_t indx)
 {
-  return mailimap_set_add_interval(set, index, index);
+  return mailimap_set_add_interval(set, indx, indx);
 }
 
 /* CHECK */
