@@ -41,7 +41,7 @@
 #ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
-#ifdef _MSC_VER
+#ifdef WIN32
 #	include "win_etpan.h"
 #endif
 
@@ -1293,17 +1293,17 @@ struct mailimf_date_time * mailimf_get_current_date(void)
   return mailimf_get_date(now);
 }
 
-struct mailimf_date_time * mailimf_get_date(time_t time)
+struct mailimf_date_time * mailimf_get_date(time_t t)
 {
   struct tm gmt;
   struct tm lt;
   int off;
   struct mailimf_date_time * date_time;
 
-  if (gmtime_r(&time, &gmt) == NULL)
+  if (gmtime_r(&t, &gmt) == NULL)
     return NULL;
 
-  if (localtime_r(&time, &lt) == NULL)
+  if (localtime_r(&t, &lt) == NULL)
     return NULL;
 
   off = (mail_mkgmtime(&lt) - mail_mkgmtime(&gmt)) / (60 * 60) * 100;
