@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmbox.c,v 1.44 2006/06/26 11:50:27 hoa Exp $
+ * $Id: mailmbox.c,v 1.47 2008/02/20 22:35:48 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -39,7 +39,7 @@
 
 #include "mailmbox.h"
 
-#ifdef _MSC_VER
+#ifdef WIN32
 #	include "win_etpan.h"
 #else
 #	include <sys/file.h>
@@ -257,8 +257,6 @@ static int mailmbox_validate_lock(struct mailmbox_folder * folder,
 
   if ((buf.st_mtime != folder->mb_mtime) ||
       ((size_t) buf.st_size != folder->mb_mapping_size)) {
-    int r;
-
     mailmbox_unmap(folder);
     mailmbox_close(folder);
 
@@ -1329,7 +1327,7 @@ static int copy_to_old_file(char * source_filename,
 
 int mailmbox_expunge_no_lock(struct mailmbox_folder * folder)
 {
-  char tmpfile[PATH_MAX];
+  char tmp_file[PATH_MAX];
   int r;
   int res;
   int dest_fd;
@@ -1345,18 +1343,18 @@ int mailmbox_expunge_no_lock(struct mailmbox_folder * folder)
     return MAILMBOX_NO_ERROR;
   }
 
-  snprintf(tmpfile, PATH_MAX, "%sXXXXXX", folder->mb_filename);
+  snprintf(tmp_file, PATH_MAX, "%sXXXXXX", folder->mb_filename);
   old_mask = umask(0077);
-  dest_fd = mkstemp(tmpfile);
+  dest_fd = mkstemp(tmp_file);
   umask(old_mask);
   
   if (dest_fd < 0) {
     /* fallback to tmp dir */
     
-    snprintf(tmpfile, PATH_MAX, TMPDIR "/etpan-unsafe-XXXXXX");
+    snprintf(tmp_file, PATH_MAX, TMPDIR "/etpan-unsafe-XXXXXX");
     
     old_mask = umask(0077);
-    dest_fd = mkstemp(tmpfile);
+    dest_fd = mkstemp(tmp_file);
     umask(old_mask);
     
     if (dest_fd < 0) {
@@ -1365,7 +1363,7 @@ int mailmbox_expunge_no_lock(struct mailmbox_folder * folder)
     }
   }
   
-  r = mailmbox_expunge_to_file_no_lock(tmpfile, dest_fd,
+  r = mailmbox_expunge_to_file_no_lock(tmp_file, dest_fd,
 				       folder, &size);
   if (r != MAILMBOX_NO_ERROR) {
     res = r;
@@ -1374,20 +1372,20 @@ int mailmbox_expunge_no_lock(struct mailmbox_folder * folder)
   
   close(dest_fd);
 
-  r = rename(tmpfile, folder->mb_filename);
+  r = rename(tmp_file, folder->mb_filename);
   if (r < 0) {
     mailmbox_unmap(folder);
     mailmbox_close(folder);
     
     /* fallback on copy to old file */
     
-    r = copy_to_old_file(tmpfile, folder->mb_filename, size);
+    r = copy_to_old_file(tmp_file, folder->mb_filename, size);
     if (r != MAILMBOX_NO_ERROR) {
       res = r;
       goto err;
     }
     
-    unlink(tmpfile);
+    unlink(tmp_file);
   }
   else {
     mailmbox_unmap(folder);
@@ -1421,7 +1419,7 @@ int mailmbox_expunge_no_lock(struct mailmbox_folder * folder)
 
  unlink:
   close(dest_fd);
-  unlink(tmpfile);
+  unlink(tmp_file);
  err:
   return res;
 }
