@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmime_write_generic.c,v 1.6 2006/06/26 11:50:27 hoa Exp $
+ * $Id: mailmime_write_generic.c,v 1.10 2008/01/14 17:13:53 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -51,7 +51,7 @@
 #ifdef HAVE_SYS_MMAN_H
 #	include <sys/mman.h>
 #endif
-#ifdef _MSC_VER
+#ifdef WIN32
 #	include "win_etpan.h"
 #endif
 
@@ -770,15 +770,21 @@ static int mailmime_part_write_driver(int (* do_write)(void *, const char *, siz
   int r;
   char * boundary;
   int istext;
-
+  int res;
+  
   istext = TRUE;
   boundary = NULL;
 
   if (build_info->mm_content_type != NULL) {
     if (build_info->mm_type == MAILMIME_MULTIPLE) {
       boundary = mailmime_extract_boundary(build_info->mm_content_type);
-      if (boundary == NULL)
-        return MAILIMF_ERROR_INVAL;
+      if (boundary == NULL) {
+        boundary = mailmime_generate_boundary();
+        if (boundary == NULL) {
+          res = MAILIMF_ERROR_MEMORY;
+          goto err;
+        }
+      }
     }
     
     if (build_info->mm_content_type->ct_type->tp_type ==
@@ -796,8 +802,10 @@ static int mailmime_part_write_driver(int (* do_write)(void *, const char *, siz
 
     if (build_info->mm_data.mm_single != NULL) {
       r = mailmime_data_write_driver(do_write, data, col, build_info->mm_data.mm_single, istext);
-      if (r != MAILIMF_NO_ERROR)
-        return r;
+      if (r != MAILIMF_NO_ERROR) {
+        res = r;
+        goto free_boundary;
+      }
     }
     
     break;
@@ -812,15 +820,16 @@ static int mailmime_part_write_driver(int (* do_write)(void *, const char *, siz
     if (build_info->mm_data.mm_multipart.mm_preamble != NULL) {
       r = mailmime_data_write_driver(do_write, data, col,
           build_info->mm_data.mm_multipart.mm_preamble, TRUE);
-      if (r != MAILIMF_NO_ERROR)
-	return r;
+      if (r != MAILIMF_NO_ERROR) {
+        res = r;
+        goto free_boundary;
+      }
       
       r = mailimf_string_write_driver(do_write, data, col, "\r\n", 2);
-      if (r != MAILIMF_NO_ERROR)
-	return r;
-#if 0
-      * col = 0;
-#endif
+      if (r != MAILIMF_NO_ERROR) {
+        res = r;
+        goto free_boundary;
+      }
     }
 
     /* sub-parts */
@@ -835,70 +844,79 @@ static int mailmime_part_write_driver(int (* do_write)(void *, const char *, siz
 
       if (!first) {
 	r = mailimf_string_write_driver(do_write, data, col, "\r\n", 2);
-	if (r != MAILIMF_NO_ERROR)
-	  return r;
-#if 0
-	* col = 0;
-#endif
+	if (r != MAILIMF_NO_ERROR) {
+          res = r;
+          goto free_boundary;
+        }
       }
       else {
 	first = FALSE;
       }
 
       r = mailimf_string_write_driver(do_write, data, col, "--", 2);
-      if (r != MAILIMF_NO_ERROR)
-	return r;
+      if (r != MAILIMF_NO_ERROR) {
+        res = r;
+        goto free_boundary;
+      }
 
       r = mailimf_string_write_driver(do_write, data, col, boundary, strlen(boundary));
-      if (r != MAILIMF_NO_ERROR)
-	return r;
+      if (r != MAILIMF_NO_ERROR) {
+        res = r;
+        goto free_boundary;
+      }
 
       r = mailimf_string_write_driver(do_write, data, col, "\r\n", 2);
-      if (r != MAILIMF_NO_ERROR)
-	return r;
-#if 0
-      * col = 0;
-#endif
+      if (r != MAILIMF_NO_ERROR) {
+        res = r;
+        goto free_boundary;
+      }
 
       r = mailmime_sub_write_driver(do_write, data, col, subpart);
-      if (r != MAILIMF_NO_ERROR)
-	return r;
+      if (r != MAILIMF_NO_ERROR) {
+        res = r;
+        goto free_boundary;
+      }
     }
     
     r = mailimf_string_write_driver(do_write, data, col, "\r\n", 2);
-    if (r != MAILIMF_NO_ERROR)
-      return r;
-#if 0
-    * col = 0;
-#endif
+    if (r != MAILIMF_NO_ERROR) {
+      res = r;
+      goto free_boundary;
+    }
     
     r = mailimf_string_write_driver(do_write, data, col, "--", 2);
-    if (r != MAILIMF_NO_ERROR)
-      return r;
+    if (r != MAILIMF_NO_ERROR) {
+      res = r;
+      goto free_boundary;
+    }
     
     r = mailimf_string_write_driver(do_write, data, col, boundary, strlen(boundary));
-    if (r != MAILIMF_NO_ERROR)
-      return r;
+    if (r != MAILIMF_NO_ERROR) {
+      res = r;
+      goto free_boundary;
+    }
 
     r = mailimf_string_write_driver(do_write, data, col, "--", 2);
-    if (r != MAILIMF_NO_ERROR)
-      return r;
-
+    if (r != MAILIMF_NO_ERROR) {
+      res = r;
+      goto free_boundary;
+    }
 
     /* epilogue */
 
     r = mailimf_string_write_driver(do_write, data, col, "\r\n", 2);
-    if (r != MAILIMF_NO_ERROR)
-      return r;
-#if 0
-    * col = 0;
-#endif
+    if (r != MAILIMF_NO_ERROR) {
+      res = r;
+      goto free_boundary;
+    }
     
     if (build_info->mm_data.mm_multipart.mm_epilogue != NULL) {
       r = mailmime_data_write_driver(do_write, data, col,
           build_info->mm_data.mm_multipart.mm_epilogue, TRUE);
-      if (r != MAILIMF_NO_ERROR)
-	return r;
+      if (r != MAILIMF_NO_ERROR) {
+        res = r;
+        goto free_boundary;
+      }
     }
 
     break;
@@ -908,14 +926,18 @@ static int mailmime_part_write_driver(int (* do_write)(void *, const char *, siz
     if (build_info->mm_data.mm_message.mm_fields != NULL) {
       r = mailimf_fields_write_driver(do_write, data, col,
           build_info->mm_data.mm_message.mm_fields);
-      if (r != MAILIMF_NO_ERROR)
-        return r;
+      if (r != MAILIMF_NO_ERROR) {
+        res = r;
+        goto free_boundary;
+      }
     }
 
     if (build_info->mm_mime_fields != NULL) {
       r = mailmime_fields_write_driver(do_write, data, col, build_info->mm_mime_fields);
-      if (r != MAILIMF_NO_ERROR)
-        return r;
+      if (r != MAILIMF_NO_ERROR) {
+        res = r;
+        goto free_boundary;
+      }
     }
 
     /* encapsuled message */
@@ -923,14 +945,23 @@ static int mailmime_part_write_driver(int (* do_write)(void *, const char *, siz
     if (build_info->mm_data.mm_message.mm_msg_mime != NULL) {
       r = mailmime_sub_write_driver(do_write, data, col,
           build_info->mm_data.mm_message.mm_msg_mime);
-      if (r != MAILIMF_NO_ERROR)
-        return r;
+      if (r != MAILIMF_NO_ERROR) {
+        res = r;
+        goto free_boundary;
+      }
     }
     break;
     
   }
   
+  free(boundary);
+  
   return MAILIMF_NO_ERROR;
+  
+ free_boundary:
+  free(boundary);
+ err:
+  return res;
 }
 
 
@@ -1422,6 +1453,10 @@ int mailmime_quoted_printable_write_driver(int (* do_write)(void *, const char *
       break;
     }
   }
-
+  
+  r = write_remaining(do_write, data, col, &start, &len);
+  if (r != MAILIMF_NO_ERROR)
+    return r;
+  
   return MAILIMF_NO_ERROR;
 }
