@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: newsnntp.c,v 1.26 2007/06/29 23:09:51 hoa Exp $
+ * $Id: newsnntp.c,v 1.28 2008/02/20 22:15:53 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,7 +41,7 @@
 
 
 #include <stdio.h>
-#ifndef _MSC_VER
+#ifndef WIN32
 #	include <unistd.h>
 #	include <netinet/in.h>
 #	include <netdb.h>
@@ -321,13 +321,13 @@ static int newsnntp_get_content(newsnntp * f, char ** result,
   }
 }
 
-int newsnntp_head(newsnntp * f, uint32_t index, char ** result,
+int newsnntp_head(newsnntp * f, uint32_t indx, char ** result,
 		  size_t * result_len)
 {
   char command[NNTP_STRING_SIZE];
   int r;
 
-  snprintf(command, NNTP_STRING_SIZE, "HEAD %i\r\n", index);
+  snprintf(command, NNTP_STRING_SIZE, "HEAD %i\r\n", indx);
   r = send_command(f, command);
   if (r == -1)
     return NEWSNNTP_ERROR_STREAM;
@@ -337,13 +337,13 @@ int newsnntp_head(newsnntp * f, uint32_t index, char ** result,
 
 /* ******************** ARTICLE ******************************** */
 
-int newsnntp_article(newsnntp * f, uint32_t index, char ** result,
+int newsnntp_article(newsnntp * f, uint32_t indx, char ** result,
 		     size_t * result_len)
 {
   char command[NNTP_STRING_SIZE];
   int r;
 
-  snprintf(command, NNTP_STRING_SIZE, "ARTICLE %i\r\n", index);
+  snprintf(command, NNTP_STRING_SIZE, "ARTICLE %i\r\n", indx);
   r = send_command(f, command);
   if (r == -1)
     return NEWSNNTP_ERROR_STREAM;
@@ -367,13 +367,13 @@ int newsnntp_article_by_message_id(newsnntp * f, char * msg_id,
 
 /* ******************** BODY ******************************** */
 
-int newsnntp_body(newsnntp * f, uint32_t index, char ** result,
+int newsnntp_body(newsnntp * f, uint32_t indx, char ** result,
 		  size_t * result_len)
 {
   char command[NNTP_STRING_SIZE];
   int r;
 
-  snprintf(command, NNTP_STRING_SIZE, "BODY %i\r\n", index);
+  snprintf(command, NNTP_STRING_SIZE, "BODY %i\r\n", indx);
   r = send_command(f, command);
   if (r == -1)
     return NEWSNNTP_ERROR_STREAM;
