@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: newsnntp_ssl.c,v 1.15 2006/06/26 11:50:28 hoa Exp $
+ * $Id: newsnntp_ssl.c,v 1.17 2006/12/26 13:13:24 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -54,6 +54,13 @@
 #define SERVICE_TYPE_TCP "tcp"
 
 int newsnntp_ssl_connect(newsnntp * f, const char * server, uint16_t port)
+{
+  return newsnntp_ssl_connect_with_callback(f, server, port,
+      NULL, NULL);
+}
+
+int newsnntp_ssl_connect_with_callback(newsnntp * f, const char * server, uint16_t port,
+    void (* callback)(struct mailstream_ssl_context * ssl_context, void * data), void * data)
 {
   int s;
   mailstream * stream;
@@ -70,10 +77,10 @@ int newsnntp_ssl_connect(newsnntp * f, const char * server, uint16_t port)
   if (s == -1)
     return NEWSNNTP_ERROR_CONNECTION_REFUSED;
 
-  stream = mailstream_ssl_open(s);
+  stream = mailstream_ssl_open_with_callback(s, callback, data);
   if (stream == NULL) {
     close(s);
-    return NEWSNNTP_ERROR_CONNECTION_REFUSED;
+    return NEWSNNTP_ERROR_SSL;
   }
 
   return newsnntp_connect(f, stream);
