@@ -71,7 +71,7 @@ int parse_options(int argc, char ** argv,
     char ** path, char ** cache_directory,
     char ** flags_directory)
 {
-  int index;
+  int indx;
   static struct option long_options[] = {
     {"driver",   1, 0, 'd'},
     {"server",   1, 0, 's'},
@@ -90,7 +90,7 @@ int parse_options(int argc, char ** argv,
   char location[PATH_MAX];
   char * env_user;
 
-  index = 0;
+  indx = 0;
 
   * driver = MBOX_STORAGE;
   * server = NULL;
